//
// Copyright (C) 1999-2006 WideStudio/MWT Project Team
//
// Permission is hereby granted, free of charge, to any person obtaining a copy
// of this software and associated documentation files (the "Software"), to
// deal in the Software without restriction, including without limitation the
// rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
// sell copies of the Software, and to permit persons to whom the Software is
// furnished to do so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in
// all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
// THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
// SOFTWARE.

#ifndef WSCFUNCTIONLIST_H
#define WSCFUNCTIONLIST_H

#include <WScom.h>
#include <WSClistData.h>

class WSCfunction;

class WSCfunctionRegister{
  protected:
    WSCfunction* _function;
  public:
    WSDLEX32 WSCfunctionRegister(char*,void*);
    WSDLEX32 virtual ~WSCfunctionRegister();
};

class WSCfunctionList{
  protected:
    WSClistData  _function_list;
  public:
    WSDLEX32 void         addFunction(WSCfunction*);
    WSDLEX32 WSCfunction* addFunction(char* name,void* proc);

    WSDLEX32 WSCfunction* getFunction(char*);
    WSDLEX32 void*        getFunctionAddr(char*);

    WSDLEX32 void delFunction(WSCfunction*);
    WSDLEX32 void delAll();
};
extern WSDLEX WSCfunctionList*  WSGIappFunctionList();
#endif
